==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/sn_blocked.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_blocked.php" method="post">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="4" class="txt_title" align="right">
						<?php echo $lang['hdr_blocked'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blocked)) {
				foreach($blocked as $key => $i):
				?>
				<tr>
					<td>

						<?php echo $i['profile_nic'];?><br />
					</td>
					<td>
						<?php echo $i['block_datetime'];?><br />
					</td>
					<td>
						<?php echo $i['block_description'];?><br />
					</td>
					<td align="right">
						<a href="sn_blocked.php?unblock_user_id=<?php echo $i['user_id_blocked'];?>"><?php echo $lang['href_unblock'];?></a><br />
					</td>

				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_blocked'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/template/am_default/sn_blocked.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_blocked.php" method="post">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<table border="0" cellspacing="0" cellpadding="4" width="100%" class="table_stnd">
				<tr>
					<td colspan="4" class="txt_title" align="right">
						<?php echo $lang['hdr_blocked'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blocked)) {
				foreach($blocked as $key => $i):
				?>
				<tr>
					<td>

						<?php echo $i['profile_nic'];?><br />
					</td>
					<td>
						<?php echo $i['block_datetime'];?><br />
					</td>
					<td>
						<?php echo $i['block_description'];?><br />
					</td>
					<td align="right">
						<a href="sn_blocked.php?unblock_user_id=<?php echo $i['user_id_blocked'];?>"><?php echo $lang['href_unblock'];?></a><br />
					</td>

				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_blocked'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
		</td>
	</tr>
</table>
</form>
